#
# spec file for package container-selinux
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global selinuxtype targeted
%global moduletype services
%global modulenames container
# Usage: _format var format
# Expand 'modulenames' into various formats as needed
# Format must contain '$x' somewhere to do anything useful
%global _format() export %{1}=""; for x in %{modulenames}; do %{1}+=%{2}; %{1}+=" "; done;
# Version of SELinux we were using
%define selinux_policyver %(rpm -q selinux-policy --qf '%%{version}')
Name:           container-selinux
Version:        2.238.0
Release:        1.1
Summary:        SELinux policies for container runtimes
License:        GPL-2.0-only
URL:            https://github.com/containers/container-selinux
Source0:        container-selinux-%{version}.tar.xz
BuildRequires:  selinux-policy
BuildRequires:  selinux-policy-devel
BuildRequires:  selinux-policy-%{selinuxtype}
Requires:       selinux-policy >= %(rpm -q selinux-policy --qf '%%{version}-%%{release}')
Requires(posttrans): policycoreutils
Requires(posttrans): /usr/bin/sed
Requires(posttrans): selinux-policy-base >= %{selinux_policyver}
Requires(posttrans): selinux-policy-targeted >= %{selinux_policyver}
Requires(posttrans): selinux-tools
BuildArch:      noarch

%description
SELinux policy modules for use with container runtimes.

%prep
%setup -q

%build
%make_build

%install
# install policy modules
%_format MODULES $x.pp.bz2
install -d %{buildroot}%{_datadir}/selinux/packages
install -d -p %{buildroot}%{_datadir}/selinux/devel/include/services
install -p -m 644 container.if %{buildroot}%{_datadir}/selinux/devel/include/services
install -m 0644 $MODULES %{buildroot}%{_datadir}/selinux/packages
install -d %{buildroot}/%{_datadir}/containers/selinux
install -m 644 container_contexts %{buildroot}/%{_datadir}/containers/selinux/contexts
install -d %{buildroot}%{_datadir}/udica/templates
install -m 0644 udica-templates/*.cil %{buildroot}%{_datadir}/udica/templates
install -d %{buildroot}%{_mandir}/man8/
install -pm 0644 container_selinux.8 %{buildroot}%{_mandir}/man8/

%check

%pre
%selinux_relabel_pre -s %{selinuxtype}

%postun
if [ $1 -eq 0 ]; then
   %selinux_modules_uninstall -s %{selinuxtype} %{modulenames} docker
fi

%posttrans
# Install all modules in a single transaction
if [ $1 -eq 1 ]; then
   %{_sbindir}/setsebool -P -N virt_use_nfs=1 virt_sandbox_use_all_caps=1
fi
%_format MODULES %{_datadir}/selinux/packages/$x.pp.bz2
%{_sbindir}/semodule -n -s %{selinuxtype} -r container 2> /dev/null ||:
%{_sbindir}/semodule -n -s %{selinuxtype} -d docker 2> /dev/null ||:
%{_sbindir}/semodule -n -s %{selinuxtype} -d gear 2> /dev/null ||:
%selinux_modules_install -s %{selinuxtype} $MODULES
. %{_sysconfdir}/selinux/config
sed -e "\|container_file_t|h; \${x;s|container_file_t||;{g;t};a\\" -e "container_file_t" -e "}" -i %{_sysconfdir}/selinux/${SELINUXTYPE}/contexts/customizable_types
matchpathcon -qV %{_sharedstatedir}/containers || restorecon -R %{_sharedstatedir}/containers &> /dev/null || :
%selinux_relabel_post -s %{selinuxtype}

%files
%license LICENSE
%doc README.md
%{_datadir}/selinux/*
%dir %{_datadir}/containers
%dir %{_datadir}/containers/selinux
%{_datadir}/containers/selinux/contexts
%dir %{_datadir}/udica
%dir %{_datadir}/udica/templates
%{_datadir}/udica/templates/*
%{_mandir}/man8/container_selinux.8*

%changelog
* Mon Jun  2 2025 Johannes Segitz <jsegitz@suse.com>
- Update to version 2.238.0:
  * label /run/sysctl.d correctly on creation
* Tue Apr 29 2025 jsegitz@suse.com
- Update to version 2.237.0:
  * bootc/install_t: allow transition to container_runtime_t
  * Allow containers to mask parts of their /proc
* Mon Mar 31 2025 jsegitz@suse.com
- Update to version 2.236.0:
  * Allow super privileged containers to use RealtimeKit for scheduling
  * Add container_ro_file_t to the podman artifact store
* Wed Mar  5 2025 cathy.hu@suse.com
- Update to version 2.235.0:
  * Bump to v2.235.0
  * OWNERS: add wrabcak and zpytela
  * OWNERS: initial commit
  * container_log{reader,writer}_t: allow watch file
  * RPM: Update gating config
  * Enable aarch64 testing
  * TMT: simplify podman tests
  * feat: support /var/lib/crio
* Tue Feb  4 2025 Robert Frohl <rfrohl@suse.com>
- OBS service file: use the tagged commit for archive versioning and don't
  just archive the latest changes from the main branch using the latest tag
* Fri Jan 10 2025 rfrohl@suse.com
- Update to version 2.234.2:
  * TMT: enable epel idomatically
  * Packit: switch back to fedora-all
  * RPM: Bump Epoch to 4
  * rpm: ship manpage
  * Add proper labeling for RamaLama
  * Packit: remove rhel / epel jobs
  * packit: remove unused file
* Thu Jan  9 2025 Cathy Hu <cathy.hu@suse.com>
- Add BuildRequires selinux-policy-%%{selinuxtype} to enable building
  for SLFO. Might be removed in the future again when 1231252
  is fixed.
* Thu Nov  7 2024 cathy.hu@suse.com
- Update to version 2.233.0:
  * container_engine_t: small change to allow non root exec in a container
  * RPM: explicitly list ghosted paths and skip mode verification
  * container-selinux install on non selinux-policy-targeted systems (#332)
  * set container_log_t type for /var/log/kube-apiserver
  * Allow kubelet_t to create a sock file kubelet_var_lib_t
  * dontaudit spc_t to mmap_zero
  * Packit: update targets (#330)
  * container_engine_t: another round of small improvements (#327)
  * Allow container_device_plugin_t to use the network (#325)
  * RPM: cleanup changelog (#324)
  * TMT: Simplify tests
* Wed Jul 10 2024 cathy.hu@suse.com
- Update to version 2.232.1:
  * Bump to v2.232.1
  * TMT: fix srpm download syntax on rawhide
  * Bump to 2.232.0
  * Packit: remove `update_release` key from downstream jobs (#313)
  * Update container-selinux.8 man page
  * Add ownership of /usr/share/udica (#312)
  * Packit/TMT: upstream maintenance of downstream gating tests
  * extend container_engine_t again
  * Allow spc_t to use localectl
  * Allow spc_t to use timedatectl
  * introduce container_use_xserver_devices boolean to allow GPU access
* Mon May  6 2024 jsegitz@suse.com
- Update to version 2.231.0:
  * Allow container domains to communicate with spc_t unix_stream_sockets
  * Move to %%posttrans to ensure selinux-policy got updated before
    the commands run (bsc#1221720)
* Wed Apr 10 2024 Cathy Hu <cathy.hu@suse.com>
- Manual update to version 2.230.0+git4.a8e389d to include this
  commit that is needed for the main selinux-policy update to work:
  * Rename all /var/run file context entries to /run
* Wed Apr 10 2024 Cathy Hu <cathy.hu@suse.com>
- Update to version 2.230.0:
  * Move to tar_scm based packaging: added _service and _servicedata
  * Allow containers to unmount file systems
  * Add buildah as a container_runtime_exec_t label
  * Additional rules for container_user_t
  * improve container_engine_t
* Thu Jan 11 2024 Johannes Segitz <jsegitz@suse.com>
- Update to version 2.228:
  * Allow container domains to watch fifo_files
  * container_engine_t: improve for podman in kubernetes case
  * Allow spc_t to transition to install_t domain
  * Default to allowing containers to use dri devices
  * Allow access to BPF Filesystems
  * Fix kubernetes transition rule
  * Label kubensenter as well as kubenswrapper
  * Allow container domains to execute container_runtime_tmpfs_t files
  * Allow container domains to ptrace themselves
  * Allow container domains to use container_runtime_tmpfs_t as an entrypoint
  * Add boolean to allow containers to use dri devices
  * Give containers access to pod resources endpoint
  * Label kubenswrapper kubelet_exec_t
* Wed Sep 20 2023 Johannes Segitz <jsegitz@suse.com>
- Update to version 2.222:
  * Allow containers to read/write inherited dri devices
* Tue Aug 15 2023 Johannes Segitz <jsegitz@suse.com>
- Update to version 2.221:
  * Allow containers to shutdown sockets inherited from container
    runtimes
  * Allow spc_t to use execmod libraries on container file systems
  * Add boolean to allow containers to read all cert files
  * More MLS Policy allow rules
  * Allow container runtimes using pasta bind icmp_socket to port_t
  * Fix spc_t transitions from container_runtime_domain
* Tue May 23 2023 Johannes Segitz <jsegitz@suse.com>
- Update to version 2.215.0:
  * Add some MLS rules to policy
  * Allow container runtime to dyntransition to spc_t
  * Tighten controls on confined users
  * Add labels for /var/lib/shared
  * Cleanup entrypoint definitions
  * Allow container_device_plugin_t access to debugfs
  * Allow containers which use devices to map them
* Mon Apr 24 2023 Johannes Segitz <jsegitz@suse.com>
- Update to version 2.211.0:
  * Don't transition to initrc_t domains from spc_t
  * Add tunable to allow sshd_t to launch container engines
  * Allow syslogd_t gettatr on inheritited runtime tmpfs files
  * Add container_file_t and container_ro_file_t as user_home_type
  * Set default context for local-path-provisioner
  * Allow daemon to send dbus messages to spc_t by
* Wed Mar 29 2023 Johannes Segitz <jsegitz@suse.com>
- Update to version 2.206.0:
  * Allow unconfined domains to transition to container_runtime_t
  * Allow container domains to transition to install_t
  * Allow avirt_sandbox_domain to manage container_file_t types
  * Allow containers to watch sysfs_t directories
  * Allow spc_t to transption to rpm_script_t
  * Add support to new user_namespace access check
  * Smaller permission changes for container_init_t
- Drop spc.patch, is now included
* Mon Jan 16 2023 Frederic Crozat <fcrozat@suse.com>
- Update to version 2.198.0:
  * Fix spc_t transition rules on tmpfs_t
- Changes from 2.197.0:
  * Add boolean containers_use_ecryptfs policy
- Changes from 2.195.1:
  * Readd missing allow rules for container_t
- Changes from 2.194.0:
  * Allow syslogd_t to use tmpfs files created by container runtime
- Changes from 2.193.0:
  * Allow containers to mount tmpfs_t file systems
  * Label spc_t as a init initrc daemon
  * Allow userdomains to run containers
- Changes from 2.191.0:
  * Create container_logwriter_t type
- Changes from 2.190.1:
  * Support BuildKit
  * container.fc: Set label for kata-agent
  * support nerdctl
- Changes from 2.190.0:
  * Packit: initial enablement
  * Allow iptables to list directories labeled as container_file_t
- Changes from 2.189.0:
  * Dont audit searching other processes in /proc.
* Thu Jan 12 2023 Johannes Segitz <jsegitz@suse.com>
- Rename spc_timedated.patch to spc.patch
- Update spc.patch to allow privileged containers to use
  localectl (bsc#1207077)
* Wed Jan 11 2023 Johannes Segitz <jsegitz@suse.com>
- Add spc_timedated.patch to allow privileged containers to use
  timedatectl (bsc#1207054)
* Thu Jul 14 2022 Johannes Segitz <jsegitz@suse.com>
- Update to version 2.188.0:
  * Allow confined containers to mount overlay filesystems
  Fixed bsc#1201348
* Wed Jun 22 2022 Frederic Crozat <fcrozat@suse.com>
- Update to version 2.187.0:
  * Allow container domains to use /dev/zero
- Changes from 2.186.0:
  * Create policy for a container_device_t
  * Allow containers to shutdown & setopt userdomain:sockets
- Changes from 2.183.0:
  * Allow containers to inherit all socket classes from container runtimes.
- Changes from 2.182.0:
  * Allow containers to inherit all socket classes
- Changes from 2.181.0:
  * Allow socket activated domains for tcp sockets from init_t and userdomains.
* Tue Mar 22 2022 Johannes Segitz <jsegitz@suse.com>
- Add udica templates to the package
* Fri Mar 18 2022 Johannes Segitz <jsegitz@suse.com>
- Update to version 2.180.0
  * Allow container domains to read/write kvm_device_t
  * Update kublet mappings to inlcude /usr/local/*
  * Allow container domains to use container runtime tcp and udp sockets
  * Alow containers to use unix_stream_sockets leaked from container runtimes
  * Allow userdomains to execute conmon_exec_t and use it as an entrypoint
  * Allow conmon_exec_t as an entrypoint
  * Add container_use_devices boolean to allow containers to use any device
  * Add explicit range transition for conmon
  * Add missing dbus class declaration into container_runtime_run()
  * Remove lockdown allow rules
  * Remove k3s fcontexts
  * Allow container domains to be used by user roles
- Changed source url to allow for download via source service
* Fri Nov 12 2021 Richard Brown <rbrown@suse.com>
- Update to version 2.171.0
  * Define kubernetes_file_t as a config_type
  * Allow containers to be socket activated by user domains and by systemd.
  * Allow iptables to use fifo files of a container runtime
  * Allow container_runtime create all tmpfs content as container_runtime_tmpfs_t
  * Allow containers to create lnk_file on tmpfs_t directories.
* Mon Aug  9 2021 Johannes Segitz <jsegitz@suse.com>
- Update to version 2.164.2
  * Don't setup users for writing to pid_sockets
  * Allow container engines to be started from the staff user.
  * Allow spc_t domains to set bpf rules on any domain
  * Add support for k3s
* Fri Apr 23 2021 Johannes Segitz <jsegitz@suse.com>
- Fix container runtime binary labels (bsc#1185030). You need to
  relable at least /usr/sbin if you're affected
* Tue Feb 23 2021 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.158.0
  - Add nfs remount support
  - Allow containers to execmod on nfs, samba and cephs remote shares
  - Allow confined users to send dbus messages to container_runtime
* Mon Jan 11 2021 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.154.0
  - Allow confined user domains to run confined container domains.
  - Allow all containers to use nfs shares, iff virt_use_nfs boolean
    is enabled.
  - Allow containers to read nsfs file systems.
  - KVM Container need to use tunnel sockets created by runtime.
* Tue Nov  3 2020 Ludwig Nussel <lnussel@suse.de>
- Don't use BuildRequires based on shell script output. OBS can't
  evaluate that.
* Thu Oct 29 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.150.0
  - Add additional allow rules for kvm based containers using
    virtiofsd.
* Wed Oct 14 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.145.0
  - Add support for kubernetes_file_t
  - Allow container_t to open existing tun/tap
* Wed Aug 12 2020 Thorsten Kukuk <kukuk@suse.com>
- Minimize BuildRequires
* Mon Aug 10 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 2.143.0
  - support containerd/cri
* Wed Aug  5 2020 Thorsten Kukuk <kukuk@suse.com>
- Initial version
